@@ -11,4 +11,6 @@ from .traj import *
 from .quality import *
 from .busgps import *
 from .getbusdata import *
-__version__ = '0.1.18'
\ No newline at end of file
+from .visualizion import *
+from CoordinatesConverter import *
+__version__ = '0.1.21'
\ No newline at end of file
